%define anolis_release 1
%bcond_without tests
%bcond_without optional_tests
%bcond_without timeout
%bcond_without docs

Name:		pytest
Version:	7.1.3
Release:	%{anolis_release}%{?dist}
Summary:	Simple powerful testing with Python
License:	MIT
URL:		https://pytest.org
Source0:	https://github.com/pytest-dev/pytest/archive/refs/tags/%{name}-%{version}.tar.gz

Patch0:	        pytest-7.1.3-fix-xfails.patch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  pyproject-rpm-macros >= 0-51

%if %{with tests}
BuildRequires:  python3-hypothesis >= 3.56
BuildRequires:  python3-pygments >= 2.7.2
BuildRequires:  python3-xmlschema	
%if %{with optional_tests}
BuildRequires:  python3-argcomplete
BuildRequires:  python3-decorator
BuildRequires:  python3-jinja2
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-numpy
BuildRequires:  python3-pexpect
BuildRequires:  python3-pytest-xdist
BuildRequires:  python3-twisted
BuildRequires:  /usr/bin/lsof
%endif
%if %{with timeout}
BuildRequires:  python3-pytest-timeout
%endif
%endif

%if %{with docs}
BuildRequires:  %{_bindir}/rst2html
BuildRequires:  python3-pluggy >= 1
BuildRequires:  python3-pygments-pytest
BuildRequires:  python3-Pallets-Sphinx-Themes
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx-removed-in
BuildRequires:  python3-sphinxcontrib-trio
BuildRequires:  (python3-sphinxcontrib-inkscapeconverter if inkscape)
BuildRequires:  make
%endif

BuildArch:      noarch

%description
The pytest framework makes it easy to write small tests, yet scales to support
complex functional testing for applications and libraries.

%package -n python3-%{name}
Summary:        Simple powerful testing with Python
Provides:       pytest = %{version}-%{release}

%description -n python3-%{name}
The pytest framework makes it easy to write small tests, yet scales to support
complex functional testing for applications and libraries.

%if %{with docs}
%package -n python3-%{name}-doc
Summary:        Documentation files for %{name}
Requires:       python3-%{name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{name}-doc
The %{name}-doc package contains documentation files for %{name}.
%endif

%prep
%autosetup -n %{name}-%{version} -p1


%generate_buildrequires
%pyproject_buildrequires -r


%build
%pyproject_wheel

%if %{with docs}
for l in doc/* ; do
  %make_build -C $l html PYTHONPATH=%{pyproject_build_lib}
done	
%endif

%install
%pyproject_install
%pyproject_save_files _pytest pytest

	
mv %{buildroot}%{_bindir}/pytest %{buildroot}%{_bindir}/pytest-%{python3_version}
ln -snf pytest-%{python3_version} %{buildroot}%{_bindir}/pytest-3
mv %{buildroot}%{_bindir}/py.test %{buildroot}%{_bindir}/py.test-%{python3_version}
ln -snf py.test-%{python3_version} %{buildroot}%{_bindir}/py.test-3
 
# We use 3.X per default
ln -snf pytest-%{python3_version} %{buildroot}%{_bindir}/pytest
ln -snf py.test-%{python3_version} %{buildroot}%{_bindir}/py.test

# remove shebangs from all scripts
find %{buildroot}%{python3_sitelib} \
     -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;

	
%if %{with tests}
%check
%global __pytest %{buildroot}%{_bindir}/pytest
# optional_tests deps contain pytest-xdist, so we can use it to run tests faster
%pytest testing %{?with_timeout:--timeout=30} %{?with_optional_tests:-n auto} -rs
%endif

%files -n python3-%{name} -f %{pyproject_files}
%license AUTHORS LICENSE
%{_bindir}/pytest
%{_bindir}/pytest-3
%{_bindir}/pytest-%{python3_version}
%{_bindir}/py.test
%{_bindir}/py.test-3
%{_bindir}/py.test-%{python3_version}

%if %{with docs}
%files -n python3-%{name}-doc
%doc CHANGELOG.rst
%doc README.rst
%doc CONTRIBUTING.rst
%doc RELEASING.rst
%endif

%changelog
* Wed Sep 14 2022 happy_orange <songnannan@linux.alibaba.com> - 7.0.3-1
- Init package from upstream
